@@ -368,7 +368,7 @@ sub getConfig {
 
   # 抓取设备命令脚本，输入不分页命令加速输出
   my $commands = $self->getCommands;
-  my $ret      = decode_utf8 $self->execCommands( $commands->@* );
+  my $ret      = $self->execCommands( $commands->@* );
 
   # 判断是否执行成功
   if ( $ret->{success} == 1 ) {
@@ -441,8 +441,21 @@ sub execCommands {
     }
     # 脚本执行正常,则拼接字符串
     $result .= $buff;
-    $result =~ s/\r\n/\n/g;
-    $result =~ s/\015//g;
+
+    # 通过 NOTEPAD++ 可以观察数据 015(CR)
+    # H3C 部分交换机乱码
+    $result =~ s/\s{15}\015//g;
+    # PA防火墙部分字串乱码 | 010(空格) (033) ESC
+    $result =~ s/\s\010//g;
+    $result =~ s/\033\[\?1.*=\015//g;
+    $result =~ s/\033\[7m\033\[27m\033\[K(\015)?//g;
+    $result =~ s/\033\[K//g;
+    $result =~ s/\033\[\?1l\033\>//g;
+
+    # 通用字串修正
+    $result =~ s/\r?\n$//g;
+    $result =~ s/\s\^H//g;
+    $result =~ s/(\015)+//g;
   }
 
   # 将字串转换为 utf8
